/* 
 * This plugin adds commands that halfd will interpret.
 *
 * The plugin is *not* required!  halfd and adminmod will work together
 * just fine without it!  This just adds a few commands that will 
 * allow you to control the behaviour of halfd from adminmod.
 * 
 * For more information visit http://www.halfd.org
 *
 * INSTRUCTIONS FOR USE:
 *	In order for this plugin to function, it must first be compiled.  Copy
 *	this file to your Admin/scripting/examples directory.
 *
 *	Run the following command from that directory:
 *	./compile.sh plugin_halfd.sma
 *
 *	To install the plugin, copy Admin/scripting/binaries/plugin_halfd.amx to
 *	your $HLDIR/<mod>/dlls directory.
 *
 *	Then add the plugin to your $HLDIR/<mod>/plugin.ini file.
 *
 *	Don't forget to set "adminmod=1" in halfd.cfg! 
 *
 *
 * New Commands:
 *
 *	admin_hd             - Sends a console command to halfd (e.g. TKOFF)
 *	admin_hd_voteon      - Enables halfd voting
 *	admin_hd_voteoff     - Disables halfd voting
 *	admin_hd_startvote   - Starts a halfd vote
 *	admin_hd_stopvote    - Stops a halfd vote
 *	admin_hd_force <x>   - Forces <x> to win a vote
 *	admin_hd_tkon        - Enables halfd TK checking
 *	admin_hd_tkoff       - Disables halfd TK checking
 *	admin_hd_foulon      - Enables halfd foul-language checking
 *	admin_hd_fouloff     - Disables halfd foul-language checking
 *	admin_hd_pingon      - Enables halfd ping checking
 *	admin_hd_pingoff     - Disables halfd ping checking
 *	admin_hd_weapon      - Enables halfd weapon checking
 *	admin_hd_weapoff     - Disables halfd weapon checking
 *	admin_hd_weap <x>    - Sets disallowed weapons to <x> for current map run
 *	admin_hd_weapdef <x> - Sets disallowed weapons to <x> for all maps
 *	admin_hd_maxoff      - Disables 'maxmod' feature of halfd
 *	admin_hd_decay       - Decays all player penalty counts by 1
 *	admin_hd_decayp <x>  - Decays player penalty counts for <x> by 1
 *	admin_hd_fortune     - Broadcast a random fortune
 *	admin_hd_hboff       - Turn off HalfBot
 *	admin_hd_hbon        - Turn on HalfBot
 *	admin_hd_tauntsoff   - Turn off weapon/suicide taunts
 *	admin_hd_tautnson    - Turn on weapon/suicide taunts
 *
 *	admin_bot_kick       - Allows kicking of bots without crashing the server.
 *
 * FYI: I had to disable plugin_message to get AM 2.50+ to work with bots.
 *
 */

#include <core>
#include <console>
#include <string>
#include <admin>
#include <adminlib>

/* This is the same as ACCESS_KICK, change if you like. */
#define ACCESS_BOTKICK  128

/* Gives access to ALL halfd commands - note that this is the
 * same as giving rcon access!!!
 */
#define ACCESS_HALFD    65536

/* Gives access to VOTEON/VOTEOFF/STARTVOTE/STOPVOTE/FORCE */
#define ACCESS_HALFD_VOTE 1024

/* Gives access to TKON/TKOFF */
#define ACCESS_HALFD_TK 1024

/* Gives access to FOULON/FOULOFF */
#define ACCESS_HALFD_FOUL 1024

/* Gives access to PINGON/PINGOFF */
#define ACCESS_HALFD_PING 1024

/* Gives access to WEAPON/WEAPOFF/WEAP/WEAPDEF */
#define ACCESS_HALFD_WEAPON 1024

/* Gives access to MAXOFF */
#define ACCESS_HALFD_MAX 1024

/* Gives access to DECAY/DECAYPLAYER */
#define ACCESS_HALFD_DECAY 1024

new STRING_VERSION[MAX_DATA_LENGTH] = "2.50.0";

public admin_bot_kick(HLCommand,HLData,HLUserName,UserIndex) {
	new Command[MAX_COMMAND_LENGTH];
	new Data[MAX_DATA_LENGTH];
	new kick_user[MAX_DATA_LENGTH];
	new Reason[MAX_DATA_LENGTH];
	new Text[MAX_TEXT_LENGTH];
	new User[MAX_NAME_LENGTH];
	new Name[MAX_NAME_LENGTH];
	new UserID = 0;
	new strUserID[MAX_NUMBER_LENGTH];
	new WONID = 0;
	new iIndex = 0;

	convert_string(HLCommand,Command,MAX_COMMAND_LENGTH);
	convert_string(HLData,Data,MAX_DATA_LENGTH);
	convert_string(HLUserName,User,MAX_NAME_LENGTH);

	strbreak(Data,kick_user,Reason,MAX_DATA_LENGTH);
	if ( check_user(kick_user) == 1) {
		get_userindex(kick_user, iIndex);
		if (playerinfo(iIndex,Name,MAX_NAME_LENGTH,UserID,WONID) != 0) {
			if( WONID == 0 ) {
				say_command( User, Command, Name );
				numtostr( UserID, strUserID );
				snprintf( Text, MAX_TEXT_LENGTH, "BOT-KICK %s", strUserID );
			} else {
				snprintf( Text, MAX_TEXT_LENGTH, "%s tried to kick non-bot %s.", User, Name );
				selfmessage( "admin_bot_kick can only be used on bots!" );
			}

			/* Just log it, don't execute anything, halfd will pick this up. */
			log( Text );
		}
	} else {
		selfmessage("Unrecognized player: ");
		selfmessage(kick_user);
	}
	return PLUGIN_HANDLED;
}

public admin_hd( HLCommand, HLData, HLUserName, UserIndex ) {
	new Command[MAX_COMMAND_LENGTH];
	new Data[MAX_DATA_LENGTH];
	new User[MAX_NAME_LENGTH];
	new Text[MAX_NAME_LENGTH];
		
	convert_string( HLCommand, Command, MAX_COMMAND_LENGTH );
	convert_string( HLData, Data, MAX_DATA_LENGTH );
	convert_string( HLUserName, User, MAX_NAME_LENGTH );

	/* Command = command executed (e.g. admin_hd)
	 * Data    = argument to Command (e.g. TKOFF)
	 * User    = user that executed the command
	 *
	 */

	snprintf( Text, MAX_TEXT_LENGTH, "halfd: %s", Data );
	log( Text );

	say_command( User, Command, Data );

	return PLUGIN_HANDLED;
}

public admin_hd_tkon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: TKON" );
	return PLUGIN_HANDLED;
}

public admin_hd_tkoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: TKOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_startvote( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: STARTVOTE" );
	return PLUGIN_HANDLED;
}

public admin_hd_stopvote( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: STOPVOTE" );
	return PLUGIN_HANDLED;
}

public admin_hd_voteon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: VOTEON" );
	return PLUGIN_HANDLED;
}

public admin_hd_voteoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: VOTEOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_force( HLCommand, HLData, HLUserName, UserIndex ) {
	new Data[MAX_DATA_LENGTH];
	new Text[MAX_NAME_LENGTH];
		
	convert_string( HLData, Data, MAX_DATA_LENGTH );

	snprintf( Text, MAX_TEXT_LENGTH, "halfd: FORCE %s", Data );
	log( Text );

	return PLUGIN_HANDLED;
}

public admin_hd_foulon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: FOULON" );
	return PLUGIN_HANDLED;
}

public admin_hd_fouloff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: FOULOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_weapon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: WEAPON" );
	return PLUGIN_HANDLED;
}

public admin_hd_weapoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: WEAPOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_weap( HLCommand, HLData, HLUserName, UserIndex ) {
	new Data[MAX_DATA_LENGTH];
	new Text[MAX_NAME_LENGTH];
		
	convert_string( HLData, Data, MAX_DATA_LENGTH );

	snprintf( Text, MAX_TEXT_LENGTH, "halfd: WEAP %s", Data );
	log( Text );

	return PLUGIN_HANDLED;
}

public admin_hd_weapdef( HLCommand, HLData, HLUserName, UserIndex ) {
	new Data[MAX_DATA_LENGTH];
	new Text[MAX_NAME_LENGTH];
		
	convert_string( HLData, Data, MAX_DATA_LENGTH );

	snprintf( Text, MAX_TEXT_LENGTH, "halfd: WEAPDEF %s", Data );
	log( Text );

	return PLUGIN_HANDLED;
}

public admin_hd_pingon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: PINGON" );
	return PLUGIN_HANDLED;
}

public admin_hd_pingoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: PINGOFF" );
	return PLUGIN_HANDLED;
}


public admin_hd_maxoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: MAXOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_decay( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: DECAY" );
	return PLUGIN_HANDLED;
}

public admin_hd_decayp( HLCommand, HLData, HLUserName, UserIndex ) {
	new Data[MAX_DATA_LENGTH];
	new Text[MAX_NAME_LENGTH];
		
	convert_string( HLData, Data, MAX_DATA_LENGTH );

	snprintf( Text, MAX_TEXT_LENGTH, "halfd: DECAYPLAYER %s", Data );
	log( Text );

	return PLUGIN_HANDLED;
}

public admin_hd_fortune( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: FORTUNE" );
	return PLUGIN_HANDLED;
}

public admin_hd_hbon( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: HBON" );
	return PLUGIN_HANDLED;
}

public admin_hd_hboff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: HBOFF" );
	return PLUGIN_HANDLED;
}

public admin_hd_tauntson( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: TAUNTSON" );
	return PLUGIN_HANDLED;
}

public admin_hd_tauntsoff( HLCommand, HLData, HLUserName, UserIndex ) {
	log( "halfd: TAUNTSOFF" );
	return PLUGIN_HANDLED;
}

public plugin_init() {
	plugin_registerinfo("halfd Plugin","halfd Admin Mod commands.",STRING_VERSION);
	
	plugin_registercmd("admin_bot_kick","admin_bot_kick",ACCESS_BOTKICK,"admin_bot_kick <target or WONID or IP> [Reason]: Kicks a bot without crashing the server.  Requires halfd." );
	plugin_registercmd("admin_hd","admin_hd",ACCESS_HALFD,"admin_hd <command>: Sends a command to halfd." );
	plugin_registercmd("admin_hd_tkon","admin_hd_tkon",ACCESS_HALFD_TK,"admin_hd_tkon: Enables halfd TK checking." );
	plugin_registercmd("admin_hd_tkoff","admin_hd_tkoff",ACCESS_HALFD_TK,"admin_hd_tkoff: Disables halfd TK checking." );
	plugin_registercmd("admin_hd_startvote","admin_hd_startvote",ACCESS_HALFD_VOTE,"admin_hd_startvote: Starts a halfd voting session." );
	plugin_registercmd("admin_hd_stopvote","admin_hd_stopvote",ACCESS_HALFD_VOTE,"admin_hd_stopvote: Stops a halfd voting session." );
	plugin_registercmd("admin_hd_voteon","admin_hd_voteon",ACCESS_HALFD_VOTE,"admin_hd_voteon: Enables halfd voting." );
	plugin_registercmd("admin_hd_voteoff","admin_hd_voteoff",ACCESS_HALFD_VOTE,"admin_hd_voteoff: Disables halfd voting." );
	plugin_registercmd("admin_hd_force","admin_hd_force",ACCESS_HALFD_VOTE,"admin_hd_force <map>: Forces <map> to win a halfd vote." );
	plugin_registercmd("admin_hd_foulon","admin_hd_foulon",ACCESS_HALFD_FOUL,"admin_hd_foulon: Enables halfd foul-language checking." );
	plugin_registercmd("admin_hd_fouloff","admin_hd_fouloff",ACCESS_HALFD_FOUL,"admin_hd_fouloff: Disables halfd foul-language checking." );
	plugin_registercmd("admin_hd_pingon","admin_hd_pingon",ACCESS_HALFD_PING,"admin_hd_pingon: Enables halfd ping checking." );
	plugin_registercmd("admin_hd_pingoff","admin_hd_pingoff",ACCESS_HALFD_PING,"admin_hd_pingoff: Disables halfd ping checking." );
	plugin_registercmd("admin_hd_weapon","admin_hd_weapon",ACCESS_HALFD_WEAPON,"admin_hd_weapon: Enables halfd weapon checking." );
	plugin_registercmd("admin_hd_weapoff","admin_hd_weapoff",ACCESS_HALFD_WEAPON,"admin_hd_weapoff: Disables halfd weapon checking." );
	plugin_registercmd("admin_hd_weap","admin_hd_weap",ACCESS_HALFD_WEAPON,"admin_hd_weap <weapons>: Sets disallowed weapons for the current map run." );
	plugin_registercmd("admin_hd_weapdef","admin_hd_weapdef",ACCESS_HALFD_WEAPON,"admin_hd_weapdef <weapons>: Sets disallowed weapons for all maps." );
	plugin_registercmd("admin_hd_maxoff","admin_hd_maxoff",ACCESS_HALFD_MAX,"admin_hd_maxoff: Disables halfd 'maxmod' feature." );
	plugin_registercmd("admin_hd_decay","admin_hd_decay",ACCESS_HALFD_DECAY,"admin_hd_decay: Decays ALL player penalties by one count." );
	plugin_registercmd("admin_hd_decayp","admin_hd_decayp",ACCESS_HALFD_DECAY,"admin_hd_decayp <id>: Decays penalties for <id> by one count." );
	plugin_registercmd("admin_hd_fortune","admin_hd_fortune",ACCESS_HALFD,"admin_hd_fortune: Brodcast a random fortune." );
	plugin_registercmd("admin_hd_hboff","admin_hd_hboff",ACCESS_HALFD,"admin_hd_hboff: Turns off HalfBot." );
	plugin_registercmd("admin_hd_hbon","admin_hd_hbon",ACCESS_HALFD,"admin_hd_hbon: Turns on HalfBot." );
	plugin_registercmd("admin_hd_tauntsoff","admin_hd_tauntsoff",ACCESS_HALFD,"admin_hd_tauntsoff: Turns off weapon/suicide taunts." );
	plugin_registercmd("admin_hd_tauntson","admin_hd_tauntson",ACCESS_HALFD,"admin_hd_tauntson: Turns on weapon/suicide taunts." );
	
	return PLUGIN_CONTINUE;
}
